import { aws_ec2 as ec2 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Construct properties for the EKS-D cluster
 */
export interface ClusterProps {
    /**
     * VPC for the cluster
     *
     * @default - get or create a VPC
     */
    readonly vpc?: ec2.IVpc;
    /**
     * The default EC2 instance type
     *
     * @default t3.large
     */
    readonly defaultInstanceType?: ec2.InstanceType;
    /**
     * number of instances
     *
     * @default 1
     */
    readonly capacitySize?: number;
    /**
     * AMI for the EKS-D instance node
     *
     * @default - The latest AMI from ubuntu-focal-20.04-amd64-server
     */
    readonly machineImage?: ec2.IMachineImage;
    /**
     * Print AMI ID in the output
     *
     * @default - true
     */
    readonly outputAmiId?: boolean;
    /**
     * Create EC2 spot instnce for the cluster node
     *
     * @default - false
     */
    readonly spot?: boolean;
}
export declare enum SpotInstanceType {
    ONE_TIME = "one-time",
    PERSISTENT = "persistent"
}
/**
 * Represents the EKS-D cluster
 */
export declare class Cluster extends Construct {
    private readonly defaultInstanceType;
    constructor(scope: Construct, id: string, props?: ClusterProps);
    private _createAutoScalingGroup;
}
/**
 * The AMI provider to get the latest Ubuntu Linux AMI
 */
export declare class UbumtuAmiProvider {
    readonly scope: Construct;
    readonly userData: ec2.UserData;
    constructor(scope: Construct, userData: ec2.UserData);
    get amiId(): ec2.IMachineImage;
}
